@@ -75,15 +75,22 @@ void MainWindow::engineStateChanged( Phonon::State state )
 
     m_timeLabel->setVisible(enable);
     m_audioView->enableDemo(!enable);
+
     if (!enable) {
         // Force out of full screen.
         if (isFullScreen) {
             setFullScreen(false);
         }
-        if (m_mainView->currentWidget() != m_loadView) {
-            m_mainView->setCurrentWidget(m_loadView);
+    }
+
+    if (!m_currentWidget && state == Phonon::PlayingState) {
+        if (TheStream::hasVideo()) {
+            m_currentWidget = engine();
+        } else {
+            m_currentWidget = m_audioView;
+            if (!isMaximized())
+                resize(m_currentWidget->minimumSize());
         }
-    } else if (state != Phonon::PausedState && m_mainView->currentWidget() == m_loadView) {
         toggleLoadView();
     }
 
@@ -147,10 +154,10 @@ void MainWindow::engineMediaChanged(Phonon::MediaSource /*newSource*/)
 #endif
         if( url.scheme() != QLatin1String( "dvd" ) && url.scheme() != QLatin1String( "vcd" ) && !url.toDisplayString().isEmpty()) {
             KConfigGroup config = KConfigGroup( KSharedConfig::openConfig(), "General" );
-            const QString prettyUrl = url.toDisplayString();
-            QStringList urls = config.readPathEntry( "Recent Urls", QStringList() );
-            urls.removeAll( prettyUrl );
-            config.writePathEntry( "Recent Urls", urls << prettyUrl );
+            const auto list = config.readPathEntry( "Recent Urls", QStringList() );
+            auto urls = QUrl::fromStringList(list);
+            urls.removeAll(url);
+            config.writePathEntry( "Recent Urls", QUrl::toStringList(urls << url) );
             emit m_loadView->reloadRecentlyList();
         }
 #ifndef NO_SKIP_PR0N
